[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE)
[![Build Status](https://travis-ci.org/polyaxon/polyaxon-gpustat.svg?branch=master)](https://travis-ci.org/polyaxon/polyaxon-gpustat)
[![PyPI version](https://badge.fury.io/py/polyaxon-gpustat.svg)](https://badge.fury.io/py/polyaxon-gpustat)
[![Slack](https://img.shields.io/badge/chat-on%20slack-aadada.svg?logo=slack&longCache=true)](https://join.slack.com/t/polyaxon/shared_invite/enQtMzQ0ODc2MDg1ODc0LWY2ZTdkMTNmZjBlZmRmNjQxYmYwMTBiMDZiMWJhODI2ZTk0MDU4Mjg5YzA5M2NhYzc5ZjhiMjczMDllYmQ2MDg)

GPUSTATS
--------

This is a utility function to query gpu stats. this is a modified fork of [wookayin/gpustat](https://github.com/wookayin/gpustat).

Quick Installation
------------------

Install from [PyPI][pypi_gpustat]:

```
pip install polyaxon-gpustat
```

To install the latest version (master branch) via pip:

```
pip install git+https://github.com/polyaxon/polyaxon-gpustat.git@master
```

License
-------

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-gpustat.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-gpustat?ref=badge_large)
